Instructions
============

The built-in :class:`~piquasso.api.instruction.Instruction` classes in Piquasso.

.. toctree::
   :maxdepth: 3
   :hidden:

   preparations
   gates
   measurements
   channels


.. grid:: 3

   .. grid-item-card::  Preparations
      :link: preparations
      :link-type: doc

      Instructions for state preparations.

   .. grid-item-card::  Gates
      :link: gates
      :link-type: doc

      Instructions for applying quantum gates.

   .. grid-item-card::  Measurements
      :link: measurements
      :link-type: doc

      Instructions to carry out measurements.

   .. grid-item-card::  Channels
      :link: channels
      :link-type: doc

      Instructions for applying quantum channels.